@@ -1,4 +1,4 @@
 #!/bin/bash
 
 echo -e "XXXXXXX\tBr\tBr.Br" \
-    | scripts/smi_isomorphism
+    | smi_isomorphism
