@@ -1,4 +1,4 @@
 #!/bin/bash
 
 echo -e "XXXXXXX\tC(C1=CC=C(C(=O)O)C=C1)(=O)O.N1=C(C=CC=C1)C1=CC=CC2=CC=CC(=C12)C1=NC=CC=C1\tOC(=O)c1ccc(cc1)C(=O)O.n1ccc(c2cccc3cccc(c23)c2ccncc2)cc1" \
-    | scripts/smi_isomorphism
+    | smi_isomorphism
