@@ -1,4 +1,4 @@
 #!/bin/bash
 
 echo -e "XXXXXXX\tFC1=C(C(=O)N)C=C(C=C1C1=CC=NC=C1)F\tFc1c(C(=O)Nc2ccncc2)cc(F)cc1" \
-    | scripts/smi_isomorphism
+    | smi_isomorphism
