@@ -1,4 +1,4 @@
 #!/bin/bash
 
 echo -e "XXXXXXX\tC(\C=C\C(=O)O)(=O)O.CNC(=O)N.CNC(=O)N\tC(=C\C(=O)O)/C(=O)O.C(=O)(NC)N.C(=O)(NC)N" \
-    | scripts/smi_isomorphism
+    | smi_isomorphism
