@@ -1,4 +1,4 @@
 #!/bin/bash
 
 echo -e "XXXXXXX\tF/C=C/F\tF/C=C\\F" \
-    | scripts/smi_isomorphism
+    | smi_isomorphism
