@@ -1,4 +1,4 @@
 #!/bin/bash
 
 echo -e "2000891\tS(=O)(=O)(O[C@@H]1[C@@H](F)CCCC1)c1cc2ccccc2cc1.S(=O)(=O)(O[C@H]1[C@H](F)CCCC1)c1cc2ccccc2cc1\tF([C@@]1([C@@](C(C(C(C1([H])([H]))([H])([H]))([H])([H]))([H])([H]))(O([S@@](=O)(=O)(C1(=C(C=2(C(C(=C1([H]))([H]))(=C(C(=C(C=2([H]))([H]))([H]))([H]))))([H])))))([H]))([H]))" \
-    | scripts/smi_isomorphism
+    | smi_isomorphism
